##  1. Purpose and scope
In order to provide personalized and adequate services, SAP LeanIX workspaces rely on so-called cookies and local storage objects to save and store information on the client side.
Cookies and local storage objects are a standard component of web technology and provide important functionalities to improve the user experience, but it is important that our Users understand the implications from a privacy perspective. All data collected through cookies and local storage objects are used exclusively for the purposes specified in this Cookie and Local Storage Policy (“Policy”).
This Policy explains the following:
  * What is a cookie?
  * What is a local storage?
  * Types of cookies and local storage objects used in SAP LeanIX Workspaces
  * How to block or delete cookies and local storage objects


For clarity, the present Policy only applies to cookies and local storage objects on the SAP LeanIX Platform. For a description and a list of the cookies and local storage objects that the SAP LeanIX website might also rely on, please review the relevant Cookie Policy available [here![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fcookie-policy "https://www.leanix.net/en/cookie-policy").
